@@ -26,6 +26,7 @@ use core::str::{
     FromStr,
     Utf8Error,
 };
+use std::borrow::Cow;
 
 mod asserts;
 mod features;
@@ -531,6 +532,12 @@ impl PartialEq<CompactStr> for &str {
     }
 }
 
+impl<'a> PartialEq<CompactStr> for Cow<'a, str> {
+    fn eq(&self, other: &CompactStr) -> bool {
+        *self == other.as_str()
+    }
+}
+
 impl Ord for CompactStr {
     fn cmp(&self, other: &Self) -> Ordering {
         self.as_str().cmp(other.as_str())
@@ -567,6 +574,12 @@ impl<'a> From<&'a String> for CompactStr {
     }
 }
 
+impl<'a> From<Cow<'a, str>> for CompactStr {
+    fn from(s: Cow<'a, str>) -> Self {
+        CompactStr::new(s)
+    }
+}
+
 impl FromStr for CompactStr {
     type Err = core::convert::Infallible;
     fn from_str(s: &str) -> Result<CompactStr, Self::Err> {
@@ -645,6 +658,12 @@ impl Extend<Box<str>> for CompactStr {
     }
 }
 
+impl<'a> Extend<Cow<'a, str>> for CompactStr {
+    fn extend<T: IntoIterator<Item = Cow<'a, str>>>(&mut self, iter: T) {
+        iter.into_iter().for_each(move |s| self.push_str(&s));
+    }
+}
+
 impl Extend<String> for CompactStr {
     fn extend<T: IntoIterator<Item = String>>(&mut self, iter: T) {
         self.repr.extend(iter)
