@@ -1,3 +1,4 @@
+use std::borrow::Cow;
 use std::iter::Extend;
 use std::mem::ManuallyDrop;
 use std::str::Utf8Error;
@@ -327,6 +328,12 @@ impl Extend<Box<str>> for Repr {
     }
 }
 
+impl<'a> Extend<Cow<'a, str>> for Repr {
+    fn extend<T: IntoIterator<Item = Cow<'a, str>>>(&mut self, iter: T) {
+        iter.into_iter().for_each(move |s| self.push_str(&s));
+    }
+}
+
 impl Extend<String> for Repr {
     fn extend<T: IntoIterator<Item = String>>(&mut self, iter: T) {
         iter.into_iter().for_each(move |s| self.push_str(&s));
